Class: Dependabot::Python::FileUpdater::PyprojectPreparer

Inherits:
Object
  • Object
show all
Defined in:
lib/dependabot/python/file_updater/pyproject_preparer.rb

Instance Method Summary collapse

Constructor Details

#initialize(pyproject_content:, lockfile: nil) ⇒ PyprojectPreparer

Returns a new instance of PyprojectPreparer.



16
17
18
19
# File 'lib/dependabot/python/file_updater/pyproject_preparer.rb', line 16

def initialize(pyproject_content:, lockfile: nil)
  @pyproject_content = pyproject_content
  @lockfile = lockfile
end

Instance Method Details

#add_auth_env_vars(credentials) ⇒ Object

For hosted Dependabot token will be nil since the credentials aren’t present. This is for those running Dependabot themselves and for dry-run.



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
# File 'lib/dependabot/python/file_updater/pyproject_preparer.rb', line 23

def add_auth_env_vars(credentials)
  TomlRB.parse(@pyproject_content).dig("tool", "poetry", "source")&.each do |source|
    cred = credentials&.find { |c| c["index-url"] == source["url"] }
    next unless cred

    token = cred.fetch("token", nil)
    next unless token && token.count(":") == 1

    arr = token.split(":")
    # https://python-poetry.org/docs/configuration/#using-environment-variables
    name = source["name"]&.upcase&.gsub(/\W/, "_")
    ENV["POETRY_HTTP_BASIC_#{name}_USERNAME"] = arr[0]
    ENV["POETRY_HTTP_BASIC_#{name}_PASSWORD"] = arr[1]
  end
end

#freeze_top_level_dependencies_except(dependencies) ⇒ Object

rubocop:disable Metrics/PerceivedComplexity rubocop:disable Metrics/AbcSize



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/dependabot/python/file_updater/pyproject_preparer.rb', line 59

def freeze_top_level_dependencies_except(dependencies)
  return pyproject_content unless lockfile

  pyproject_object = TomlRB.parse(pyproject_content)
  poetry_object = pyproject_object["tool"]["poetry"]
  excluded_names = dependencies.map(&:name) + ["python"]

  Dependabot::Python::FileParser::PyprojectFilesParser::POETRY_DEPENDENCY_TYPES.each do |key|
    next unless poetry_object[key]

    source_types = %w(directory file url)
    poetry_object.fetch(key).each do |dep_name, _|
      next if excluded_names.include?(normalise(dep_name))

      locked_details = locked_details(dep_name)

      next unless (locked_version = locked_details&.fetch("version"))

      next if source_types.include?(locked_details&.dig("source", "type"))

      if locked_details&.dig("source", "type") == "git"
        poetry_object[key][dep_name] = {
          "git" => locked_details&.dig("source", "url"),
          "rev" => locked_details&.dig("source", "reference")
        }
      elsif poetry_object[key][dep_name].is_a?(Hash)
        poetry_object[key][dep_name]["version"] = locked_version
      elsif poetry_object[key][dep_name].is_a?(Array)
        # if it has multiple-constraints, locking to a single version is
        # going to result in a bad lockfile, ignore
        next
      else
        poetry_object[key][dep_name] = locked_version
      end
    end
  end

  TomlRB.dump(pyproject_object)
end

#sanitizeObject



50
51
52
53
54
55
# File 'lib/dependabot/python/file_updater/pyproject_preparer.rb', line 50

def sanitize
  # {{ name }} syntax not allowed
  pyproject_content.
    gsub(/\{\{.*?\}\}/, "something").
    gsub('#{', "{")
end

#update_python_requirement(requirement) ⇒ Object



39
40
41
42
43
44
45
46
47
48
# File 'lib/dependabot/python/file_updater/pyproject_preparer.rb', line 39

def update_python_requirement(requirement)
  pyproject_object = TomlRB.parse(@pyproject_content)
  if (python_specification = pyproject_object.dig("tool", "poetry", "dependencies", "python"))
    python_req = Python::Requirement.new(python_specification)
    unless python_req.satisfied_by?(requirement)
      pyproject_object["tool"]["poetry"]["dependencies"]["python"] = "~#{requirement}"
    end
  end
  TomlRB.dump(pyproject_object)
end